==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/iviewobjectfamily.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IVIEWOBJECTFAMILY_H
#define IVIEWOBJECTFAMILY_H


#include "ifamily.h"


class iViewModule;


template<class T>
class iViewObjectFamily: public iFamily<T,iViewModule>
{
	
public:
		
	static iViewObjectFamily<T>* New(iViewModule *vm);

	inline bool IsVisible() const { return this->mVis; } 
	void Show(bool s); 
	float GetMemorySize() const;
	bool Copy(const iViewObjectFamily<T> *p);
	bool DeleteMember(int i);
	void Reset();
	void SyncWithData(int info, void *data);

protected:

	iViewObjectFamily(iViewModule *vm);
	virtual ~iViewObjectFamily(){}

	bool mVis;
};

#endif // IVIEWOBJECTFAMILY_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/iviewobjectfamily.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IVIEWOBJECTFAMILY_H
#define IVIEWOBJECTFAMILY_H


#include "iviewfamily.h"
#include "iviewmodulecomponent.h"


class iDataType;
class iObjectType;
class iViewObject;
class iViewObjectParent;


//
//  Main class
//
class iViewObjectFamily : public iViewFamily<iViewObject,iViewObjectParent>
{

public:

	static iViewObjectFamily* New(iViewModule *vm, const iObjectType &ot, bool singleInstance);
	static iViewObjectFamily* New(iViewModule *vm, const iObjectType &ot, bool singleInstance, const iDataType &dt);

	iViewObjectParent* GetParent() const;
	inline bool IsSingleInstance() const { return mIsSingleInstance; }

	virtual int CreateMember();
	virtual bool DeleteMember(int i);

protected:

	iViewObjectFamily(iViewObjectParent *parent, bool singleInstance);

	const bool mIsSingleInstance;
};

#endif // IVIEWOBJECTFAMILY_H
